@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -39,8 +39,8 @@ ImportImapSettingsAkonadiCheckJob::~ImportImapSettingsAkonadiCheckJob()
 
 bool ImportImapSettingsAkonadiCheckJob::resourceCanHaveSieveSupport(const QString &filename) const
 {
-    return filename.startsWith(QStringLiteral("akonadi_kolab_resource"))
-           || filename.startsWith(QStringLiteral("akonadi_imap_resource"));
+    return filename.startsWith(QLatin1String("akonadi_kolab_resource"))
+           || filename.startsWith(QLatin1String("akonadi_imap_resource"));
 }
 
 void ImportImapSettingsAkonadiCheckJob::start()
@@ -69,7 +69,7 @@ bool ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory,
         return false;
     }
     SieveEditorUtil::SieveServerConfig config;
-    bool isKolabSettings = filePath.contains(QStringLiteral("/akonadi_kolab_resource"));
+    bool isKolabSettings = filePath.contains(QLatin1String("/akonadi_kolab_resource"));
     KSharedConfigPtr resourceConfig = KSharedConfig::openConfig(filePath);
 
     KConfigGroup sieveGroup = resourceConfig->group(QStringLiteral("siever"));
